summaryrefslogtreecommitdiffstats
path: root/src/svnqt/client.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/svnqt/client.hpp')
-rw-r--r--src/svnqt/client.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/svnqt/client.hpp b/src/svnqt/client.hpp
index 93dcff6..95b7461 100644
--- a/src/svnqt/client.hpp
+++ b/src/svnqt/client.hpp
@@ -218,11 +218,11 @@ namespace svn
* @param depth if @a path is a folder add items recursive depending on value if it.
* @param force if true, do not error on already-versioned items.
* @param no_ignore if false don't add files or directories that match ignore patterns. When build against svn 1.2 always false
* @param add_tqparents if true, go up to the next versioned folder and add all between path and this folder.
* @exception ClientException
*/
virtual void
- add (const Path & path, svn::Depth depth,bool force=false, bool no_ignore=false, bool add_tqparents = true) throw (ClientException)=0;
+ add (const Path & path, svn::Depth depth,bool force=false, bool no_ignore=false, bool add_parents = true) throw (ClientException)=0;
/**
* Updates the file or directory.
@@ -218,11 +218,11 @@ namespace svn
* @param force if true, do not error on already-versioned items.
* @param no_ignore if false don't add files or directories that match ignore patterns. When build against svn 1.2 always false
- * @param add_tqparents if true, go up to the next versioned folder and add all between path and this folder.
+ * @param add_parents if true, go up to the next versioned folder and add all between path and this folder.
* @exception ClientException
*/